summaryrefslogtreecommitdiffstats
path: root/src/include/ipxe/efi/efi_snp.h
diff options
context:
space:
mode:
authorSimon Rettberg2026-01-28 12:53:53 +0100
committerSimon Rettberg2026-01-28 12:53:53 +0100
commit8e82785c584dc13e20f9229decb95bd17bbe9cd1 (patch)
treea8b359e59196be5b2e3862bed189107f4bc9975f /src/include/ipxe/efi/efi_snp.h
parentMerge branch 'master' into openslx (diff)
parent[prefix] Make unlzma.S compatible with 386 class CPUs (diff)
downloadipxe-openslx.tar.gz
ipxe-openslx.tar.xz
ipxe-openslx.zip
Merge branch 'master' into openslxopenslx
Diffstat (limited to 'src/include/ipxe/efi/efi_snp.h')
-rw-r--r--src/include/ipxe/efi/efi_snp.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/include/ipxe/efi/efi_snp.h b/src/include/ipxe/efi/efi_snp.h
index 96373b57d..0822466db 100644
--- a/src/include/ipxe/efi/efi_snp.h
+++ b/src/include/ipxe/efi/efi_snp.h
@@ -8,6 +8,7 @@
*/
FILE_LICENCE ( GPL2_OR_LATER );
+FILE_SECBOOT ( PERMITTED );
#include <ipxe/list.h>
#include <ipxe/netdevice.h>
@@ -30,8 +31,8 @@ struct efi_snp_device {
struct list_head list;
/** The underlying iPXE network device */
struct net_device *netdev;
- /** The underlying EFI device */
- struct efi_device *efidev;
+ /** EFI parent device handle (if any) */
+ EFI_HANDLE parent;
/** EFI device handle */
EFI_HANDLE handle;
/** The SNP structure itself */